============================
Lists of marked blog entries
============================


.. _new:

New feature
-----------


.. _mustmig:

Change in database structure
----------------------------

.. _apichange:

API change
----------


.. _mustconfig:

Change in local config
----------------------


.. _regressions:

Regression danger
-----------------

"Regression danger" means that this change possibly introduced some
regressions.




